<?php

declare(strict_types=1);

namespace Drupal\htmx_test_attachments\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;

/**
 * Returns responses for HTMX Test Attachments routes.
 */
final class HtmxTestAttachmentsController extends ControllerBase {

  /**
   * Builds the response.
   *
   * @return mixed[]
   *   A render array.
   */
  public function page(): array {
    $build['content'] = [
      '#type' => 'container',
      '#attached' => [
        'library' => [
          'htmx/drupal',
        ],
      ],
      'button' => [
        '#type' => 'inline_template',
        '#template' => '<button hx-get="{{ url }}" hx-select="{{ selector }}" hx-swap="afterend" class="button" name="replace">Click this</button>',
        '#context' => [
          'selector' => 'div.dropbutton-wrapper',
          'url' => Url::fromRoute('htmx_test_attachments.replace')->toString(),
        ],
      ],
    ];

    return $build;
  }

  /**
   * Builds the HTMX response.
   *
   * @return mixed[]
   *   A render array.
   */
  public function replace(): array {
    $build['content'] = [
      '#type' => 'dropbutton',
      '#dropbutton_type' => 'small',
      '#links' => [
        'simple_form' => [
          'title' => $this->t('Sample link 1'),
          'url' => Url::fromRoute('system.timezone')->toString(),
        ],
        'demo' => [
          'title' => $this->t('Sample link 2'),
          'url' => Url::fromRoute('<front>')->toString(),
        ],
      ],
    ];

    return $build;
  }

}
